author | Junio C Hamano <gitster@pobox.com> | |
Wed, 25 Jun 2008 20:19:22 +0000 (13:19 -0700) | ||
committer | Junio C Hamano <gitster@pobox.com> | |
Wed, 25 Jun 2008 20:19:22 +0000 (13:19 -0700) |
* sr/tests:
Hook up the result aggregation in the test makefile.
A simple script to parse the results from the testcases
Modify test-lib.sh to output stats to t/test-results/*
Conflicts:
t/test-lib.sh
Hook up the result aggregation in the test makefile.
A simple script to parse the results from the testcases
Modify test-lib.sh to output stats to t/test-results/*
Conflicts:
t/test-lib.sh
1 | 2 | |||
---|---|---|---|---|
t/test-lib.sh | patch | | diff1 | | diff2 | | blob | history |
diff --cc t/test-lib.sh
index f4f35ed4337a5cf2091b14f770988a7dd70f4361,2ad3f4a126cc70dad6d9d65aa2b322c511c9634f..401011001016ac9df11fd64bd668dd073dc0e4dc
--- 1/t/test-lib.sh
--- 2/t/test-lib.sh
+++ b/t/test-lib.sh
}
# Test the binaries we have just built. The tests are kept in
-# t/ subdirectory and are run in trash subdirectory.
+# t/ subdirectory and are run in 'trash directory' subdirectory.
- PATH=$(pwd)/..:$PATH
+ TEST_DIRECTORY=$(pwd)
+ PATH=$TEST_DIRECTORY/..:$PATH
GIT_EXEC_PATH=$(pwd)/..
GIT_TEMPLATE_DIR=$(pwd)/../templates/blt
unset GIT_CONFIG